@@ -69,6 +69,7 @@ INSTALLED_APPS = (
     'django.contrib.sites',
     'django.contrib.messages',
     'django.contrib.staticfiles',
+    'django.contrib.humanize',
     'postorius',
     'django_mailman3',
     'django_gravatar',
@@ -218,6 +219,7 @@ ACCOUNT_EMAIL_REQUIRED = True
 ACCOUNT_EMAIL_VERIFICATION = 'mandatory'
 ACCOUNT_DEFAULT_HTTP_PROTOCOL = 'https'
 ACCOUNT_UNIQUE_EMAIL = True
+ACCOUNT_EMAIL_UNKNOWN_ACCOUNTS = False
 
 SOCIALACCOUNT_PROVIDERS = {
     'openid': {
